diff --git a/CMakeLists.txt b/CMakeLists.txt
index 6fc864567b..d8f2c7d925 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -475,7 +475,6 @@ set(kwin_KDEINIT_SRCS
scripting/timer.cpp
scripting/workspace_wrapper.cpp
shadow.cpp
- shell_client.cpp
sm.cpp
thumbnailitem.cpp
toplevel.cpp
@@ -496,6 +495,7 @@ set(kwin_KDEINIT_SRCS
workspace.cpp
x11eventfilter.cpp
xcbutils.cpp
+ xdgshellclient.cpp
xkb.cpp
xwl/xwayland_interface.cpp
)
diff --git a/autotests/integration/CMakeLists.txt b/autotests/integration/CMakeLists.txt
index 42928f5bbc..433785a145 100644
--- a/autotests/integration/CMakeLists.txt
+++ b/autotests/integration/CMakeLists.txt
@@ -33,7 +33,7 @@ integrationTest(NAME testDebugConsole SRCS debug_console_test.cpp)
integrationTest(NAME testDontCrashEmptyDeco SRCS dont_crash_empty_deco.cpp)
integrationTest(WAYLAND_ONLY NAME testPlasmaSurface SRCS plasma_surface_test.cpp)
integrationTest(WAYLAND_ONLY NAME testMaximized SRCS maximize_test.cpp)
-integrationTest(WAYLAND_ONLY NAME testShellClient SRCS shell_client_test.cpp)
+integrationTest(WAYLAND_ONLY NAME testXdgShellClient SRCS xdgshellclient_test.cpp)
integrationTest(WAYLAND_ONLY NAME testDontCrashNoBorder SRCS dont_crash_no_border.cpp)
integrationTest(NAME testXwaylandSelections SRCS xwayland_selections_test.cpp)
integrationTest(WAYLAND_ONLY NAME testSceneOpenGL SRCS scene_opengl_test.cpp generic_scene_opengl_test.cpp)
@@ -51,7 +51,7 @@ integrationTest(WAYLAND_ONLY NAME testShowingDesktop SRCS showing_desktop_test.c
integrationTest(WAYLAND_ONLY NAME testDontCrashUseractionsMenu SRCS dont_crash_useractions_menu.cpp)
integrationTest(WAYLAND_ONLY NAME testKWinBindings SRCS kwinbindings_test.cpp)
integrationTest(WAYLAND_ONLY NAME testVirtualDesktop SRCS virtual_desktop_test.cpp)
-integrationTest(WAYLAND_ONLY NAME testShellClientRules SRCS shell_client_rules_test.cpp)
+integrationTest(WAYLAND_ONLY NAME testXdgShellClientRules SRCS xdgshellclient_rules_test.cpp)
integrationTest(WAYLAND_ONLY NAME testIdleInhibition SRCS idle_inhibition_test.cpp)
integrationTest(WAYLAND_ONLY NAME testColorCorrectNightColor SRCS colorcorrect_nightcolor_test.cpp)
integrationTest(WAYLAND_ONLY NAME testDontCrashCursorPhysicalSizeEmpty SRCS dont_crash_cursor_physical_size_empty.cpp)
diff --git a/autotests/integration/activation_test.cpp b/autotests/integration/activation_test.cpp
index 9aab46d487..d09a7d2c1d 100644
--- a/autotests/integration/activation_test.cpp
+++ b/autotests/integration/activation_test.cpp
@@ -23,9 +23,9 @@ along with this program. If not, see .
#include "cursor.h"
#include "platform.h"
#include "screens.h"
-#include "shell_client.h"
#include "wayland_server.h"
#include "workspace.h"
+#include "xdgshellclient.h"
#include
@@ -58,7 +58,7 @@ private:
void ActivationTest::initTestCase()
{
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
@@ -101,13 +101,13 @@ void ActivationTest::testSwitchToWindowToLeft()
// Create several clients on the left screen.
QScopedPointer surface1(Test::createSurface());
QScopedPointer shellSurface1(Test::createXdgShellStableSurface(surface1.data()));
- ShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
QVERIFY(client1);
QVERIFY(client1->isActive());
QScopedPointer surface2(Test::createSurface());
QScopedPointer shellSurface2(Test::createXdgShellStableSurface(surface2.data()));
- ShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
QVERIFY(client2);
QVERIFY(client2->isActive());
@@ -117,13 +117,13 @@ void ActivationTest::testSwitchToWindowToLeft()
// Create several clients on the right screen.
QScopedPointer surface3(Test::createSurface());
QScopedPointer shellSurface3(Test::createXdgShellStableSurface(surface3.data()));
- ShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
QVERIFY(client3);
QVERIFY(client3->isActive());
QScopedPointer surface4(Test::createSurface());
QScopedPointer shellSurface4(Test::createXdgShellStableSurface(surface4.data()));
- ShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
QVERIFY(client4);
QVERIFY(client4->isActive());
@@ -169,13 +169,13 @@ void ActivationTest::testSwitchToWindowToRight()
// Create several clients on the left screen.
QScopedPointer surface1(Test::createSurface());
QScopedPointer shellSurface1(Test::createXdgShellStableSurface(surface1.data()));
- ShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
QVERIFY(client1);
QVERIFY(client1->isActive());
QScopedPointer surface2(Test::createSurface());
QScopedPointer shellSurface2(Test::createXdgShellStableSurface(surface2.data()));
- ShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
QVERIFY(client2);
QVERIFY(client2->isActive());
@@ -185,13 +185,13 @@ void ActivationTest::testSwitchToWindowToRight()
// Create several clients on the right screen.
QScopedPointer surface3(Test::createSurface());
QScopedPointer shellSurface3(Test::createXdgShellStableSurface(surface3.data()));
- ShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
QVERIFY(client3);
QVERIFY(client3->isActive());
QScopedPointer surface4(Test::createSurface());
QScopedPointer shellSurface4(Test::createXdgShellStableSurface(surface4.data()));
- ShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
QVERIFY(client4);
QVERIFY(client4->isActive());
@@ -237,13 +237,13 @@ void ActivationTest::testSwitchToWindowAbove()
// Create several clients on the top screen.
QScopedPointer surface1(Test::createSurface());
QScopedPointer shellSurface1(Test::createXdgShellStableSurface(surface1.data()));
- ShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
QVERIFY(client1);
QVERIFY(client1->isActive());
QScopedPointer surface2(Test::createSurface());
QScopedPointer shellSurface2(Test::createXdgShellStableSurface(surface2.data()));
- ShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
QVERIFY(client2);
QVERIFY(client2->isActive());
@@ -253,13 +253,13 @@ void ActivationTest::testSwitchToWindowAbove()
// Create several clients on the bottom screen.
QScopedPointer surface3(Test::createSurface());
QScopedPointer shellSurface3(Test::createXdgShellStableSurface(surface3.data()));
- ShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
QVERIFY(client3);
QVERIFY(client3->isActive());
QScopedPointer surface4(Test::createSurface());
QScopedPointer shellSurface4(Test::createXdgShellStableSurface(surface4.data()));
- ShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
QVERIFY(client4);
QVERIFY(client4->isActive());
@@ -305,13 +305,13 @@ void ActivationTest::testSwitchToWindowBelow()
// Create several clients on the top screen.
QScopedPointer surface1(Test::createSurface());
QScopedPointer shellSurface1(Test::createXdgShellStableSurface(surface1.data()));
- ShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
QVERIFY(client1);
QVERIFY(client1->isActive());
QScopedPointer surface2(Test::createSurface());
QScopedPointer shellSurface2(Test::createXdgShellStableSurface(surface2.data()));
- ShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
QVERIFY(client2);
QVERIFY(client2->isActive());
@@ -321,13 +321,13 @@ void ActivationTest::testSwitchToWindowBelow()
// Create several clients on the bottom screen.
QScopedPointer surface3(Test::createSurface());
QScopedPointer shellSurface3(Test::createXdgShellStableSurface(surface3.data()));
- ShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
QVERIFY(client3);
QVERIFY(client3->isActive());
QScopedPointer surface4(Test::createSurface());
QScopedPointer shellSurface4(Test::createXdgShellStableSurface(surface4.data()));
- ShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
QVERIFY(client4);
QVERIFY(client4->isActive());
@@ -374,14 +374,14 @@ void ActivationTest::testSwitchToWindowMaximized()
// Create several maximized clients on the left screen.
QScopedPointer surface1(Test::createSurface());
QScopedPointer shellSurface1(Test::createXdgShellStableSurface(surface1.data()));
- ShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
QVERIFY(client1);
QVERIFY(client1->isActive());
QSignalSpy configureRequestedSpy1(shellSurface1.data(), &XdgShellSurface::configureRequested);
QVERIFY(configureRequestedSpy1.wait());
workspace()->slotWindowMaximize();
QVERIFY(configureRequestedSpy1.wait());
- QSignalSpy geometryChangedSpy1(client1, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy1(client1, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy1.isValid());
shellSurface1->ackConfigure(configureRequestedSpy1.last().at(2).value());
Test::render(surface1.data(), configureRequestedSpy1.last().at(0).toSize(), Qt::red);
@@ -389,14 +389,14 @@ void ActivationTest::testSwitchToWindowMaximized()
QScopedPointer surface2(Test::createSurface());
QScopedPointer shellSurface2(Test::createXdgShellStableSurface(surface2.data()));
- ShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
QVERIFY(client2);
QVERIFY(client2->isActive());
QSignalSpy configureRequestedSpy2(shellSurface2.data(), &XdgShellSurface::configureRequested);
QVERIFY(configureRequestedSpy2.wait());
workspace()->slotWindowMaximize();
QVERIFY(configureRequestedSpy2.wait());
- QSignalSpy geometryChangedSpy2(client2, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy2(client2, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy2.isValid());
shellSurface2->ackConfigure(configureRequestedSpy2.last().at(2).value());
Test::render(surface2.data(), configureRequestedSpy2.last().at(0).toSize(), Qt::red);
@@ -410,13 +410,13 @@ void ActivationTest::testSwitchToWindowMaximized()
// Create several clients on the right screen.
QScopedPointer surface3(Test::createSurface());
QScopedPointer shellSurface3(Test::createXdgShellStableSurface(surface3.data()));
- ShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
QVERIFY(client3);
QVERIFY(client3->isActive());
QScopedPointer surface4(Test::createSurface());
QScopedPointer shellSurface4(Test::createXdgShellStableSurface(surface4.data()));
- ShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
QVERIFY(client4);
QVERIFY(client4->isActive());
@@ -459,14 +459,14 @@ void ActivationTest::testSwitchToWindowFullScreen()
// Create several maximized clients on the top screen.
QScopedPointer surface1(Test::createSurface());
QScopedPointer shellSurface1(Test::createXdgShellStableSurface(surface1.data()));
- ShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::blue);
QVERIFY(client1);
QVERIFY(client1->isActive());
QSignalSpy configureRequestedSpy1(shellSurface1.data(), &XdgShellSurface::configureRequested);
QVERIFY(configureRequestedSpy1.wait());
workspace()->slotWindowFullScreen();
QVERIFY(configureRequestedSpy1.wait());
- QSignalSpy geometryChangedSpy1(client1, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy1(client1, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy1.isValid());
shellSurface1->ackConfigure(configureRequestedSpy1.last().at(2).value());
Test::render(surface1.data(), configureRequestedSpy1.last().at(0).toSize(), Qt::red);
@@ -474,14 +474,14 @@ void ActivationTest::testSwitchToWindowFullScreen()
QScopedPointer surface2(Test::createSurface());
QScopedPointer shellSurface2(Test::createXdgShellStableSurface(surface2.data()));
- ShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
QVERIFY(client2);
QVERIFY(client2->isActive());
QSignalSpy configureRequestedSpy2(shellSurface2.data(), &XdgShellSurface::configureRequested);
QVERIFY(configureRequestedSpy2.wait());
workspace()->slotWindowFullScreen();
QVERIFY(configureRequestedSpy2.wait());
- QSignalSpy geometryChangedSpy2(client2, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy2(client2, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy2.isValid());
shellSurface2->ackConfigure(configureRequestedSpy2.last().at(2).value());
Test::render(surface2.data(), configureRequestedSpy2.last().at(0).toSize(), Qt::red);
@@ -495,13 +495,13 @@ void ActivationTest::testSwitchToWindowFullScreen()
// Create several clients on the bottom screen.
QScopedPointer surface3(Test::createSurface());
QScopedPointer shellSurface3(Test::createXdgShellStableSurface(surface3.data()));
- ShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::blue);
QVERIFY(client3);
QVERIFY(client3->isActive());
QScopedPointer surface4(Test::createSurface());
QScopedPointer shellSurface4(Test::createXdgShellStableSurface(surface4.data()));
- ShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client4 = Test::renderAndWaitForShown(surface4.data(), QSize(100, 50), Qt::blue);
QVERIFY(client4);
QVERIFY(client4->isActive());
diff --git a/autotests/integration/activities_test.cpp b/autotests/integration/activities_test.cpp
index 6fa465cd5c..df6d881797 100644
--- a/autotests/integration/activities_test.cpp
+++ b/autotests/integration/activities_test.cpp
@@ -27,7 +27,7 @@ along with this program. If not, see .
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "xcbutils.h"
#include
@@ -58,7 +58,7 @@ private:
void ActivitiesTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
diff --git a/autotests/integration/buffer_size_change_test.cpp b/autotests/integration/buffer_size_change_test.cpp
index 2b41eb8b2c..b0c9ffdc20 100644
--- a/autotests/integration/buffer_size_change_test.cpp
+++ b/autotests/integration/buffer_size_change_test.cpp
@@ -20,7 +20,7 @@ along with this program. If not, see .
#include "generic_scene_opengl_test.h"
#include "composite.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include
@@ -61,7 +61,7 @@ void BufferSizeChangeTest::testShmBufferSizeChange()
QVERIFY(!shellSurface.isNull());
// set buffer size
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
// add a first repaint
@@ -73,7 +73,7 @@ void BufferSizeChangeTest::testShmBufferSizeChange()
// now change buffer size
Test::render(surface.data(), QSize(30, 10), Qt::red);
- QSignalSpy damagedSpy(client, &ShellClient::damaged);
+ QSignalSpy damagedSpy(client, &XdgShellClient::damaged);
QVERIFY(damagedSpy.isValid());
QVERIFY(damagedSpy.wait());
KWin::Compositor::self()->addRepaintFull();
@@ -98,7 +98,7 @@ void BufferSizeChangeTest::testShmBufferSizeChangeOnSubSurface()
// set buffer sizes
Test::render(surface.data(), QSize(30, 10), Qt::red);
- ShellClient *parent = Test::renderAndWaitForShown(parentSurface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *parent = Test::renderAndWaitForShown(parentSurface.data(), QSize(100, 50), Qt::blue);
QVERIFY(parent);
// add a first repaint
@@ -108,7 +108,7 @@ void BufferSizeChangeTest::testShmBufferSizeChangeOnSubSurface()
QVERIFY(swapSpy.wait());
// change buffer size of sub surface
- QSignalSpy damagedParentSpy(parent, &ShellClient::damaged);
+ QSignalSpy damagedParentSpy(parent, &XdgShellClient::damaged);
QVERIFY(damagedParentSpy.isValid());
Test::render(surface.data(), QSize(20, 10), Qt::red);
parentSurface->commit(Surface::CommitFlag::None);
diff --git a/autotests/integration/dbus_interface_test.cpp b/autotests/integration/dbus_interface_test.cpp
index 2ac4902327..079a40f113 100644
--- a/autotests/integration/dbus_interface_test.cpp
+++ b/autotests/integration/dbus_interface_test.cpp
@@ -27,7 +27,7 @@ along with this program. If not, see .
#include "platform.h"
#include "rules.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "virtualdesktops.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -61,15 +61,15 @@ private Q_SLOTS:
void cleanup();
void testGetWindowInfoInvalidUuid();
- void testGetWindowInfoShellClient_data();
- void testGetWindowInfoShellClient();
+ void testGetWindowInfoXdgShellClient_data();
+ void testGetWindowInfoXdgShellClient();
void testGetWindowInfoX11Client();
};
void TestDbusInterface::initTestCase()
{
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
@@ -112,7 +112,7 @@ void TestDbusInterface::testGetWindowInfoInvalidUuid()
QVERIFY(windowData.empty());
}
-void TestDbusInterface::testGetWindowInfoShellClient_data()
+void TestDbusInterface::testGetWindowInfoXdgShellClient_data()
{
QTest::addColumn("type");
@@ -120,7 +120,7 @@ void TestDbusInterface::testGetWindowInfoShellClient_data()
QTest::newRow("xdgWmBase") << Test::XdgShellSurfaceType::XdgShellStable;
}
-void TestDbusInterface::testGetWindowInfoShellClient()
+void TestDbusInterface::testGetWindowInfoXdgShellClient()
{
QSignalSpy clientAddedSpy(waylandServer(), &WaylandServer::shellClientAdded);
QVERIFY(clientAddedSpy.isValid());
@@ -135,7 +135,7 @@ void TestDbusInterface::testGetWindowInfoShellClient()
Test::render(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(clientAddedSpy.isEmpty());
QVERIFY(clientAddedSpy.wait());
- auto client = clientAddedSpy.first().first().value();
+ auto client = clientAddedSpy.first().first().value();
QVERIFY(client);
// let's get the window info
@@ -226,7 +226,7 @@ void TestDbusInterface::testGetWindowInfoShellClient()
// finally close window
const auto id = client->internalId();
- QSignalSpy windowClosedSpy(client, &ShellClient::windowClosed);
+ QSignalSpy windowClosedSpy(client, &XdgShellClient::windowClosed);
QVERIFY(windowClosedSpy.isValid());
shellSurface.reset();
surface.reset();
diff --git a/autotests/integration/debug_console_test.cpp b/autotests/integration/debug_console_test.cpp
index 5edf5f81eb..2921400002 100644
--- a/autotests/integration/debug_console_test.cpp
+++ b/autotests/integration/debug_console_test.cpp
@@ -22,7 +22,7 @@ along with this program. If not, see .
#include "internal_client.h"
#include "platform.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
#include "xcbutils.h"
@@ -60,7 +60,7 @@ void DebugConsoleTest::initTestCase()
{
qRegisterMetaType();
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -393,7 +393,7 @@ void DebugConsoleTest::testWaylandClient()
shellSurface.reset();
Test::flushWaylandConnection();
qDebug() << rowsRemovedSpy.count();
- QEXPECT_FAIL("wlShell", "Deleting a ShellSurface does not result in the server removing the ShellClient", Continue);
+ QEXPECT_FAIL("wlShell", "Deleting a ShellSurface does not result in the server removing the XdgShellClient", Continue);
QVERIFY(rowsRemovedSpy.wait(500));
surface.reset();
diff --git a/autotests/integration/decoration_input_test.cpp b/autotests/integration/decoration_input_test.cpp
index 4f1e3b6231..11353c97e4 100644
--- a/autotests/integration/decoration_input_test.cpp
+++ b/autotests/integration/decoration_input_test.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "touch_input.h"
#include "screenedge.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
#include
@@ -135,7 +135,7 @@ void DecorationInputTest::initTestCase()
{
qRegisterMetaType();
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
diff --git a/autotests/integration/desktop_window_x11_test.cpp b/autotests/integration/desktop_window_x11_test.cpp
index 7b223de2ef..7ece7f5f2a 100644
--- a/autotests/integration/desktop_window_x11_test.cpp
+++ b/autotests/integration/desktop_window_x11_test.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "xcbutils.h"
#include
@@ -52,7 +52,7 @@ private:
void X11DesktopWindowTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
diff --git a/autotests/integration/dont_crash_aurorae_destroy_deco.cpp b/autotests/integration/dont_crash_aurorae_destroy_deco.cpp
index 60c2f907cc..a7941ab86c 100644
--- a/autotests/integration/dont_crash_aurorae_destroy_deco.cpp
+++ b/autotests/integration/dont_crash_aurorae_destroy_deco.cpp
@@ -27,7 +27,7 @@ along with this program. If not, see .
#include "wayland_server.h"
#include "workspace.h"
#include "scene.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include
#include
@@ -54,7 +54,7 @@ private Q_SLOTS:
void DontCrashAuroraeDestroyDecoTest::initTestCase()
{
qputenv("XDG_DATA_DIRS", QCoreApplication::applicationDirPath().toUtf8());
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/dont_crash_cancel_animation.cpp b/autotests/integration/dont_crash_cancel_animation.cpp
index 99b96c491d..3b19fd5284 100644
--- a/autotests/integration/dont_crash_cancel_animation.cpp
+++ b/autotests/integration/dont_crash_cancel_animation.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "effects.h"
#include "effectloader.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
#include "scripting/scriptedeffect.h"
@@ -56,7 +56,7 @@ private Q_SLOTS:
void DontCrashCancelAnimationFromAnimationEndedTest::initTestCase()
{
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
QVERIFY(waylandServer()->init(s_socketName.toLocal8Bit()));
diff --git a/autotests/integration/dont_crash_cursor_physical_size_empty.cpp b/autotests/integration/dont_crash_cursor_physical_size_empty.cpp
index 1c9b980e3c..7661b67f97 100644
--- a/autotests/integration/dont_crash_cursor_physical_size_empty.cpp
+++ b/autotests/integration/dont_crash_cursor_physical_size_empty.cpp
@@ -24,7 +24,7 @@ along with this program. If not, see .
#include "cursor.h"
#include "effects.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -67,7 +67,7 @@ void DontCrashCursorPhysicalSizeEmpty::cleanup()
void DontCrashCursorPhysicalSizeEmpty::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/dont_crash_empty_deco.cpp b/autotests/integration/dont_crash_empty_deco.cpp
index 368d27211a..6a55a5dcae 100644
--- a/autotests/integration/dont_crash_empty_deco.cpp
+++ b/autotests/integration/dont_crash_empty_deco.cpp
@@ -27,7 +27,7 @@ along with this program. If not, see .
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include
#include
@@ -50,7 +50,7 @@ private Q_SLOTS:
void DontCrashEmptyDecorationTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/dont_crash_no_border.cpp b/autotests/integration/dont_crash_no_border.cpp
index 530e34552e..80097d6b51 100644
--- a/autotests/integration/dont_crash_no_border.cpp
+++ b/autotests/integration/dont_crash_no_border.cpp
@@ -28,7 +28,7 @@ along with this program. If not, see .
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include
#include
@@ -56,7 +56,7 @@ private Q_SLOTS:
void DontCrashNoBorder::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/dont_crash_reinitialize_compositor.cpp b/autotests/integration/dont_crash_reinitialize_compositor.cpp
index c0137d6d70..d767e64826 100644
--- a/autotests/integration/dont_crash_reinitialize_compositor.cpp
+++ b/autotests/integration/dont_crash_reinitialize_compositor.cpp
@@ -27,7 +27,7 @@ along with this program. If not, see .
#include "effects.h"
#include "platform.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -60,7 +60,7 @@ void DontCrashReinitializeCompositorTest::initTestCase()
qRegisterMetaType();
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -134,7 +134,7 @@ void DontCrashReinitializeCompositorTest::testReinitializeCompositor()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
// Make sure that only the test effect is loaded.
@@ -147,7 +147,7 @@ void DontCrashReinitializeCompositorTest::testReinitializeCompositor()
QVERIFY(!effect->isActive());
// Close the test client.
- QSignalSpy windowClosedSpy(client, &ShellClient::windowClosed);
+ QSignalSpy windowClosedSpy(client, &XdgShellClient::windowClosed);
QVERIFY(windowClosedSpy.isValid());
shellSurface.reset();
surface.reset();
diff --git a/autotests/integration/dont_crash_useractions_menu.cpp b/autotests/integration/dont_crash_useractions_menu.cpp
index 093d022967..d105d7267d 100644
--- a/autotests/integration/dont_crash_useractions_menu.cpp
+++ b/autotests/integration/dont_crash_useractions_menu.cpp
@@ -22,7 +22,7 @@ along with this program. If not, see .
#include "keyboard_input.h"
#include "platform.h"
#include "pointer_input.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "screens.h"
#include "useractions.h"
#include "wayland_server.h"
@@ -56,7 +56,7 @@ private Q_SLOTS:
void TestDontCrashUseractionsMenu::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/effects/desktop_switching_animation_test.cpp b/autotests/integration/effects/desktop_switching_animation_test.cpp
index 531bfd7769..29c5d93ece 100644
--- a/autotests/integration/effects/desktop_switching_animation_test.cpp
+++ b/autotests/integration/effects/desktop_switching_animation_test.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "effects.h"
#include "platform.h"
#include "scene.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -57,7 +57,7 @@ void DesktopSwitchingAnimationTest::initTestCase()
qputenv("XDG_DATA_DIRS", QCoreApplication::applicationDirPath().toUtf8());
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -128,7 +128,7 @@ void DesktopSwitchingAnimationTest::testSwitchDesktops()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
QCOMPARE(client->desktops().count(), 1);
QCOMPARE(client->desktops().first(), VirtualDesktopManager::self()->desktops().first());
diff --git a/autotests/integration/effects/fade_test.cpp b/autotests/integration/effects/fade_test.cpp
index a41885b1be..bcba46f190 100644
--- a/autotests/integration/effects/fade_test.cpp
+++ b/autotests/integration/effects/fade_test.cpp
@@ -23,7 +23,7 @@ along with this program. If not, see .
#include "effectloader.h"
#include "cursor.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
#include "effect_builtins.h"
@@ -55,7 +55,7 @@ private:
void FadeTest::initTestCase()
{
qputenv("XDG_DATA_DIRS", QCoreApplication::applicationDirPath().toUtf8());
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
diff --git a/autotests/integration/effects/maximize_animation_test.cpp b/autotests/integration/effects/maximize_animation_test.cpp
index 36693cd458..86ac64aed4 100644
--- a/autotests/integration/effects/maximize_animation_test.cpp
+++ b/autotests/integration/effects/maximize_animation_test.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "effects.h"
#include "platform.h"
#include "scene.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -57,7 +57,7 @@ void MaximizeAnimationTest::initTestCase()
qputenv("XDG_DATA_DIRS", QCoreApplication::applicationDirPath().toUtf8());
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -133,7 +133,7 @@ void MaximizeAnimationTest::testMaximizeRestore()
// Draw contents of the surface.
shellSurface->ackConfigure(configureRequestedSpy.last().at(2).value());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
QVERIFY(client->isActive());
QCOMPARE(client->maximizeMode(), MaximizeMode::MaximizeRestore);
@@ -157,9 +157,9 @@ void MaximizeAnimationTest::testMaximizeRestore()
QVERIFY(!effect->isActive());
// Maximize the client.
- QSignalSpy geometryChangedSpy(client, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy(client, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy.isValid());
- QSignalSpy maximizeChangedSpy(client, qOverload(&ShellClient::clientMaximizedStateChanged));
+ QSignalSpy maximizeChangedSpy(client, qOverload(&XdgShellClient::clientMaximizedStateChanged));
QVERIFY(maximizeChangedSpy.isValid());
workspace()->slotWindowMaximize();
diff --git a/autotests/integration/effects/minimize_animation_test.cpp b/autotests/integration/effects/minimize_animation_test.cpp
index c40fd5e24c..a548143a05 100644
--- a/autotests/integration/effects/minimize_animation_test.cpp
+++ b/autotests/integration/effects/minimize_animation_test.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "effects.h"
#include "platform.h"
#include "scene.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -59,7 +59,7 @@ void MinimizeAnimationTest::initTestCase()
qputenv("XDG_DATA_DIRS", QCoreApplication::applicationDirPath().toUtf8());
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -134,7 +134,7 @@ void MinimizeAnimationTest::testMinimizeUnminimize()
plasmaPanelShellSurface->setRole(PlasmaShellSurface::Role::Panel);
plasmaPanelShellSurface->setPosition(panelRect.topLeft());
plasmaPanelShellSurface->setPanelBehavior(PlasmaShellSurface::PanelBehavior::AlwaysVisible);
- ShellClient *panel = Test::renderAndWaitForShown(panelSurface.data(), panelRect.size(), Qt::blue);
+ XdgShellClient *panel = Test::renderAndWaitForShown(panelSurface.data(), panelRect.size(), Qt::blue);
QVERIFY(panel);
QVERIFY(panel->isDock());
QCOMPARE(panel->geometry(), panelRect);
@@ -146,7 +146,7 @@ void MinimizeAnimationTest::testMinimizeUnminimize()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::red);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::red);
QVERIFY(client);
QVERIFY(plasmaWindowCreatedSpy.wait());
QCOMPARE(plasmaWindowCreatedSpy.count(), 2);
diff --git a/autotests/integration/effects/popup_open_close_animation_test.cpp b/autotests/integration/effects/popup_open_close_animation_test.cpp
index 9a29871f95..de621fda75 100644
--- a/autotests/integration/effects/popup_open_close_animation_test.cpp
+++ b/autotests/integration/effects/popup_open_close_animation_test.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "effects.h"
#include "internal_client.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "useractions.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -66,7 +66,7 @@ void PopupOpenCloseAnimationTest::initTestCase()
qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -119,7 +119,7 @@ void PopupOpenCloseAnimationTest::testAnimatePopups()
QVERIFY(!mainWindowSurface.isNull());
QScopedPointer mainWindowShellSurface(Test::createXdgShellStableSurface(mainWindowSurface.data()));
QVERIFY(!mainWindowShellSurface.isNull());
- ShellClient *mainWindow = Test::renderAndWaitForShown(mainWindowSurface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *mainWindow = Test::renderAndWaitForShown(mainWindowSurface.data(), QSize(100, 50), Qt::blue);
QVERIFY(mainWindow);
// Load effect that will be tested.
@@ -139,7 +139,7 @@ void PopupOpenCloseAnimationTest::testAnimatePopups()
positioner.setAnchorEdge(Qt::BottomEdge | Qt::LeftEdge);
QScopedPointer popupShellSurface(Test::createXdgShellStablePopup(popupSurface.data(), mainWindowShellSurface.data(), positioner));
QVERIFY(!popupShellSurface.isNull());
- ShellClient *popup = Test::renderAndWaitForShown(popupSurface.data(), positioner.initialSize(), Qt::red);
+ XdgShellClient *popup = Test::renderAndWaitForShown(popupSurface.data(), positioner.initialSize(), Qt::red);
QVERIFY(popup);
QVERIFY(popup->isPopupWindow());
QCOMPARE(popup->transientFor(), mainWindow);
@@ -149,7 +149,7 @@ void PopupOpenCloseAnimationTest::testAnimatePopups()
QTRY_VERIFY(!effect->isActive());
// Destroy the popup, it should not be animated.
- QSignalSpy popupClosedSpy(popup, &ShellClient::windowClosed);
+ QSignalSpy popupClosedSpy(popup, &XdgShellClient::windowClosed);
QVERIFY(popupClosedSpy.isValid());
popupShellSurface.reset();
popupSurface.reset();
@@ -181,7 +181,7 @@ void PopupOpenCloseAnimationTest::testAnimateUserActionsPopup()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
// Load effect that will be tested.
@@ -236,7 +236,7 @@ void PopupOpenCloseAnimationTest::testAnimateDecorationTooltips()
QScopedPointer deco(Test::xdgDecorationManager()->getToplevelDecoration(shellSurface.data()));
QVERIFY(!deco.isNull());
deco->setMode(XdgDecoration::Mode::ServerSide);
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
QVERIFY(client->isDecorated());
diff --git a/autotests/integration/effects/scripted_effects_test.cpp b/autotests/integration/effects/scripted_effects_test.cpp
index dab3f30359..c6025eb865 100644
--- a/autotests/integration/effects/scripted_effects_test.cpp
+++ b/autotests/integration/effects/scripted_effects_test.cpp
@@ -29,7 +29,7 @@ along with this program. If not, see .
#include "effects.h"
#include "kwin_wayland_test.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "virtualdesktops.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -143,7 +143,7 @@ bool ScriptedEffectWithDebugSpy::load(const QString &name)
void ScriptedEffectsTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
@@ -511,7 +511,7 @@ void ScriptedEffectsTest::testGrab()
QVERIFY(surface);
XdgShellSurface *shellSurface = Test::createXdgShellStableSurface(surface, surface);
QVERIFY(shellSurface);
- ShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
+ XdgShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
QVERIFY(c);
QCOMPARE(workspace()->activeClient(), c);
@@ -544,7 +544,7 @@ void ScriptedEffectsTest::testGrabAlreadyGrabbedWindow()
QVERIFY(surface);
XdgShellSurface *shellSurface = Test::createXdgShellStableSurface(surface, surface);
QVERIFY(shellSurface);
- ShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
+ XdgShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
QVERIFY(c);
QCOMPARE(workspace()->activeClient(), c);
@@ -581,7 +581,7 @@ void ScriptedEffectsTest::testGrabAlreadyGrabbedWindowForced()
QVERIFY(surface);
XdgShellSurface *shellSurface = Test::createXdgShellStableSurface(surface, surface);
QVERIFY(shellSurface);
- ShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
+ XdgShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
QVERIFY(c);
QCOMPARE(workspace()->activeClient(), c);
@@ -612,7 +612,7 @@ void ScriptedEffectsTest::testUngrab()
QVERIFY(surface);
XdgShellSurface *shellSurface = Test::createXdgShellStableSurface(surface, surface);
QVERIFY(shellSurface);
- ShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
+ XdgShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
QVERIFY(c);
QCOMPARE(workspace()->activeClient(), c);
@@ -655,7 +655,7 @@ void ScriptedEffectsTest::testRedirect()
QVERIFY(surface);
XdgShellSurface *shellSurface = Test::createXdgShellStableSurface(surface, surface);
QVERIFY(shellSurface);
- ShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
+ XdgShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
QVERIFY(c);
QCOMPARE(workspace()->activeClient(), c);
@@ -733,7 +733,7 @@ void ScriptedEffectsTest::testComplete()
QVERIFY(surface);
XdgShellSurface *shellSurface = Test::createXdgShellStableSurface(surface, surface);
QVERIFY(shellSurface);
- ShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
+ XdgShellClient *c = Test::renderAndWaitForShown(surface, QSize(100, 50), Qt::blue);
QVERIFY(c);
QCOMPARE(workspace()->activeClient(), c);
diff --git a/autotests/integration/effects/slidingpopups_test.cpp b/autotests/integration/effects/slidingpopups_test.cpp
index 58e9345e5e..900bfae1e1 100644
--- a/autotests/integration/effects/slidingpopups_test.cpp
+++ b/autotests/integration/effects/slidingpopups_test.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "cursor.h"
#include "platform.h"
#include "scene.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
#include "effect_builtins.h"
@@ -61,7 +61,7 @@ private Q_SLOTS:
void SlidingPopupsTest::initTestCase()
{
qputenv("XDG_DATA_DIRS", QCoreApplication::applicationDirPath().toUtf8());
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
diff --git a/autotests/integration/effects/toplevel_open_close_animation_test.cpp b/autotests/integration/effects/toplevel_open_close_animation_test.cpp
index bcb8898bed..9cf71bdca0 100644
--- a/autotests/integration/effects/toplevel_open_close_animation_test.cpp
+++ b/autotests/integration/effects/toplevel_open_close_animation_test.cpp
@@ -27,7 +27,7 @@ along with this program. If not, see .
#include "effects.h"
#include "platform.h"
#include "scene.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -61,7 +61,7 @@ void ToplevelOpenCloseAnimationTest::initTestCase()
qRegisterMetaType();
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -137,7 +137,7 @@ void ToplevelOpenCloseAnimationTest::testAnimateToplevels()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
QVERIFY(effect->isActive());
@@ -146,7 +146,7 @@ void ToplevelOpenCloseAnimationTest::testAnimateToplevels()
// Close the test client, the effect should start animating the disappearing
// of the client.
- QSignalSpy windowClosedSpy(client, &ShellClient::windowClosed);
+ QSignalSpy windowClosedSpy(client, &XdgShellClient::windowClosed);
QVERIFY(windowClosedSpy.isValid());
shellSurface.reset();
surface.reset();
@@ -181,7 +181,7 @@ void ToplevelOpenCloseAnimationTest::testDontAnimatePopups()
QVERIFY(!mainWindowSurface.isNull());
QScopedPointer mainWindowShellSurface(Test::createXdgShellStableSurface(mainWindowSurface.data()));
QVERIFY(!mainWindowShellSurface.isNull());
- ShellClient *mainWindow = Test::renderAndWaitForShown(mainWindowSurface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *mainWindow = Test::renderAndWaitForShown(mainWindowSurface.data(), QSize(100, 50), Qt::blue);
QVERIFY(mainWindow);
// Load effect that will be tested.
@@ -201,14 +201,14 @@ void ToplevelOpenCloseAnimationTest::testDontAnimatePopups()
positioner.setAnchorEdge(Qt::BottomEdge | Qt::LeftEdge);
QScopedPointer popupShellSurface(Test::createXdgShellStablePopup(popupSurface.data(), mainWindowShellSurface.data(), positioner));
QVERIFY(!popupShellSurface.isNull());
- ShellClient *popup = Test::renderAndWaitForShown(popupSurface.data(), positioner.initialSize(), Qt::red);
+ XdgShellClient *popup = Test::renderAndWaitForShown(popupSurface.data(), positioner.initialSize(), Qt::red);
QVERIFY(popup);
QVERIFY(popup->isPopupWindow());
QCOMPARE(popup->transientFor(), mainWindow);
QVERIFY(!effect->isActive());
// Destroy the popup, it should not be animated.
- QSignalSpy popupClosedSpy(popup, &ShellClient::windowClosed);
+ QSignalSpy popupClosedSpy(popup, &XdgShellClient::windowClosed);
QVERIFY(popupClosedSpy.isValid());
popupShellSurface.reset();
popupSurface.reset();
diff --git a/autotests/integration/effects/translucency_test.cpp b/autotests/integration/effects/translucency_test.cpp
index 15b3461fff..222214217b 100644
--- a/autotests/integration/effects/translucency_test.cpp
+++ b/autotests/integration/effects/translucency_test.cpp
@@ -24,7 +24,7 @@ along with this program. If not, see .
#include "effectloader.h"
#include "cursor.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
#include "effect_builtins.h"
@@ -55,7 +55,7 @@ private:
void TranslucencyTest::initTestCase()
{
qputenv("XDG_DATA_DIRS", QCoreApplication::applicationDirPath().toUtf8());
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
diff --git a/autotests/integration/effects/windowgeometry_test.cpp b/autotests/integration/effects/windowgeometry_test.cpp
index 31a33e6e8e..e72c1c7d03 100644
--- a/autotests/integration/effects/windowgeometry_test.cpp
+++ b/autotests/integration/effects/windowgeometry_test.cpp
@@ -23,7 +23,7 @@ along with this program. If not, see .
#include "effectloader.h"
#include "cursor.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
#include "effect_builtins.h"
@@ -50,7 +50,7 @@ private Q_SLOTS:
void WindowGeometryTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
diff --git a/autotests/integration/effects/wobbly_shade_test.cpp b/autotests/integration/effects/wobbly_shade_test.cpp
index d4bc220365..d205e3b318 100644
--- a/autotests/integration/effects/wobbly_shade_test.cpp
+++ b/autotests/integration/effects/wobbly_shade_test.cpp
@@ -25,7 +25,7 @@ along with this program. If not, see .
#include "effectloader.h"
#include "cursor.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
#include "effect_builtins.h"
@@ -56,7 +56,7 @@ private Q_SLOTS:
void WobblyWindowsShadeTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
diff --git a/autotests/integration/generic_scene_opengl_test.cpp b/autotests/integration/generic_scene_opengl_test.cpp
index 02402dde5b..f7bbd71c21 100644
--- a/autotests/integration/generic_scene_opengl_test.cpp
+++ b/autotests/integration/generic_scene_opengl_test.cpp
@@ -23,7 +23,7 @@ along with this program. If not, see .
#include "cursor.h"
#include "platform.h"
#include "scene.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "effect_builtins.h"
@@ -49,7 +49,7 @@ void GenericSceneOpenGLTest::cleanup()
void GenericSceneOpenGLTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/globalshortcuts_test.cpp b/autotests/integration/globalshortcuts_test.cpp
index 382e43753d..ac26305c4a 100644
--- a/autotests/integration/globalshortcuts_test.cpp
+++ b/autotests/integration/globalshortcuts_test.cpp
@@ -24,7 +24,7 @@ along with this program. If not, see .
#include "internal_client.h"
#include "platform.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "useractions.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -65,7 +65,7 @@ void GlobalShortcutsTest::initTestCase()
{
qRegisterMetaType();
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
diff --git a/autotests/integration/idle_inhibition_test.cpp b/autotests/integration/idle_inhibition_test.cpp
index 1b93d0692a..e3ddd17809 100644
--- a/autotests/integration/idle_inhibition_test.cpp
+++ b/autotests/integration/idle_inhibition_test.cpp
@@ -19,7 +19,7 @@ along with this program. If not, see .
*********************************************************************/
#include "kwin_wayland_test.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -54,7 +54,7 @@ private Q_SLOTS:
void TestIdleInhibition::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
@@ -268,7 +268,7 @@ void TestIdleInhibition::testDontInhibitWhenUnmapped()
QCOMPARE(inhibitedSpy.count(), 1);
// Unmap the client.
- QSignalSpy hiddenSpy(c, &ShellClient::windowHidden);
+ QSignalSpy hiddenSpy(c, &XdgShellClient::windowHidden);
QVERIFY(hiddenSpy.isValid());
surface->attachBuffer(Buffer::Ptr());
surface->commit(Surface::CommitFlag::None);
@@ -280,7 +280,7 @@ void TestIdleInhibition::testDontInhibitWhenUnmapped()
QCOMPARE(inhibitedSpy.count(), 2);
// Map the client.
- QSignalSpy windowShownSpy(c, &ShellClient::windowShown);
+ QSignalSpy windowShownSpy(c, &XdgShellClient::windowShown);
QVERIFY(windowShownSpy.isValid());
Test::render(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(windowShownSpy.wait());
diff --git a/autotests/integration/input_stacking_order.cpp b/autotests/integration/input_stacking_order.cpp
index bd37440723..89e9b79b27 100644
--- a/autotests/integration/input_stacking_order.cpp
+++ b/autotests/integration/input_stacking_order.cpp
@@ -26,7 +26,7 @@ along with this program. If not, see .
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include
#include
@@ -61,7 +61,7 @@ private:
void InputStackingOrderTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
diff --git a/autotests/integration/internal_window.cpp b/autotests/integration/internal_window.cpp
index 7e9cbceb1d..9d4bf1f04f 100644
--- a/autotests/integration/internal_window.cpp
+++ b/autotests/integration/internal_window.cpp
@@ -23,7 +23,7 @@ along with this program. If not, see .
#include "effects.h"
#include "internal_client.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -185,7 +185,7 @@ void InternalWindowTest::initTestCase()
{
qRegisterMetaType();
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
diff --git a/autotests/integration/keyboard_layout_test.cpp b/autotests/integration/keyboard_layout_test.cpp
index ade80f598a..054ff8bccd 100644
--- a/autotests/integration/keyboard_layout_test.cpp
+++ b/autotests/integration/keyboard_layout_test.cpp
@@ -21,7 +21,7 @@ along with this program. If not, see .
#include "keyboard_input.h"
#include "keyboard_layout.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "virtualdesktops.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -74,7 +74,7 @@ void KeyboardLayoutTest::reconfigureLayouts()
void KeyboardLayoutTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/keymap_creation_failure_test.cpp b/autotests/integration/keymap_creation_failure_test.cpp
index dd8d7b6411..8ec33b03a9 100644
--- a/autotests/integration/keymap_creation_failure_test.cpp
+++ b/autotests/integration/keymap_creation_failure_test.cpp
@@ -21,7 +21,7 @@ along with this program. If not, see .
#include "keyboard_input.h"
#include "keyboard_layout.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "virtualdesktops.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -57,7 +57,7 @@ void KeymapCreationFailureTest::initTestCase()
qputenv("XKB_DEFAULT_VARIANT", "no");
qputenv("XKB_DEFAULT_OPTIONS", "no");
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/kwinbindings_test.cpp b/autotests/integration/kwinbindings_test.cpp
index b90ce87e68..e90790843b 100644
--- a/autotests/integration/kwinbindings_test.cpp
+++ b/autotests/integration/kwinbindings_test.cpp
@@ -22,7 +22,7 @@ along with this program. If not, see .
#include "input.h"
#include "platform.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "scripting/scripting.h"
#include "useractions.h"
#include "virtualdesktops.h"
@@ -57,7 +57,7 @@ private Q_SLOTS:
void KWinBindingsTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/lockscreen.cpp b/autotests/integration/lockscreen.cpp
index 236000d115..857d0b8438 100644
--- a/autotests/integration/lockscreen.cpp
+++ b/autotests/integration/lockscreen.cpp
@@ -27,7 +27,7 @@ along with this program. If not, see .
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include
#include
@@ -183,7 +183,7 @@ AbstractClient *LockScreenTest::showWindow()
void LockScreenTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
diff --git a/autotests/integration/move_resize_window_test.cpp b/autotests/integration/move_resize_window_test.cpp
index 4ff41aed68..87dfc93e5a 100644
--- a/autotests/integration/move_resize_window_test.cpp
+++ b/autotests/integration/move_resize_window_test.cpp
@@ -28,7 +28,7 @@ along with this program. If not, see .
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "deleted.h"
#include
@@ -94,7 +94,7 @@ void MoveResizeWindowTest::initTestCase()
{
qRegisterMetaType();
qRegisterMetaType();
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType("MaximizeMode");
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
@@ -321,7 +321,7 @@ void MoveResizeWindowTest::testResize()
QCOMPARE(moveResizedChangedSpy.count(), 2);
QCOMPARE(c->isResize(), false);
QCOMPARE(workspace()->moveResizeClient(), nullptr);
- QEXPECT_FAIL("", "ShellClient currently doesn't send final configure event", Abort);
+ QEXPECT_FAIL("", "XdgShellClient currently doesn't send final configure event", Abort);
QVERIFY(configureRequestedSpy.wait());
QCOMPARE(configureRequestedSpy.count(), 6);
states = configureRequestedSpy.last().at(1).value();
@@ -816,7 +816,7 @@ void MoveResizeWindowTest::testAdjustClientGeometryOfAutohidingX11Panel()
QCOMPARE(Workspace::self()->adjustClientPosition(testWindow, targetPoint, false), targetPoint);
// and close
- QSignalSpy windowClosedSpy(testWindow, &ShellClient::windowClosed);
+ QSignalSpy windowClosedSpy(testWindow, &XdgShellClient::windowClosed);
QVERIFY(windowClosedSpy.isValid());
shellSurface.reset();
surface.reset();
@@ -882,7 +882,7 @@ void MoveResizeWindowTest::testAdjustClientGeometryOfAutohidingWaylandPanel()
QCOMPARE(Workspace::self()->adjustClientPosition(testWindow, targetPoint, false), targetPoint);
// and destroy the panel again
- QSignalSpy panelClosedSpy(panel, &ShellClient::windowClosed);
+ QSignalSpy panelClosedSpy(panel, &XdgShellClient::windowClosed);
QVERIFY(panelClosedSpy.isValid());
plasmaSurface.reset();
panelShellSurface.reset();
@@ -893,7 +893,7 @@ void MoveResizeWindowTest::testAdjustClientGeometryOfAutohidingWaylandPanel()
QCOMPARE(Workspace::self()->adjustClientPosition(testWindow, targetPoint, false), targetPoint);
// and close
- QSignalSpy windowClosedSpy(testWindow, &ShellClient::windowClosed);
+ QSignalSpy windowClosedSpy(testWindow, &XdgShellClient::windowClosed);
QVERIFY(windowClosedSpy.isValid());
shellSurface.reset();
surface.reset();
@@ -920,7 +920,7 @@ void MoveResizeWindowTest::testResizeForVirtualKeyboard()
QVERIFY(configureRequestedSpy.wait());
client->move(100, 300);
- QSignalSpy geometryChangedSpy(client, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy(client, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy.isValid());
QCOMPARE(client->geometry(), QRect(100, 300, 500, 800));
@@ -963,7 +963,7 @@ void MoveResizeWindowTest::testResizeForVirtualKeyboardWithMaximize()
QVERIFY(configureRequestedSpy.wait());
client->move(100, 300);
- QSignalSpy geometryChangedSpy(client, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy(client, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy.isValid());
QCOMPARE(client->geometry(), QRect(100, 300, 500, 800));
@@ -1014,7 +1014,7 @@ void MoveResizeWindowTest::testResizeForVirtualKeyboardWithFullScreen()
QVERIFY(configureRequestedSpy.wait());
client->move(100, 300);
- QSignalSpy geometryChangedSpy(client, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy(client, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy.isValid());
QCOMPARE(client->geometry(), QRect(100, 300, 500, 800));
@@ -1055,7 +1055,7 @@ void MoveResizeWindowTest::testDestroyMoveClient()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
// Start moving the client.
@@ -1092,7 +1092,7 @@ void MoveResizeWindowTest::testDestroyResizeClient()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
// Start resizing the client.
@@ -1129,7 +1129,7 @@ void MoveResizeWindowTest::testUnmapMoveClient()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
// Start resizing the client.
@@ -1148,7 +1148,7 @@ void MoveResizeWindowTest::testUnmapMoveClient()
QCOMPARE(client->isResize(), false);
// Unmap the client while we're moving it.
- QSignalSpy hiddenSpy(client, &ShellClient::windowHidden);
+ QSignalSpy hiddenSpy(client, &XdgShellClient::windowHidden);
QVERIFY(hiddenSpy.isValid());
surface->attachBuffer(Buffer::Ptr());
surface->commit(Surface::CommitFlag::None);
@@ -1175,7 +1175,7 @@ void MoveResizeWindowTest::testUnmapResizeClient()
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
QVERIFY(!shellSurface.isNull());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
// Start resizing the client.
@@ -1194,7 +1194,7 @@ void MoveResizeWindowTest::testUnmapResizeClient()
QCOMPARE(client->isResize(), true);
// Unmap the client while we're resizing it.
- QSignalSpy hiddenSpy(client, &ShellClient::windowHidden);
+ QSignalSpy hiddenSpy(client, &XdgShellClient::windowHidden);
QVERIFY(hiddenSpy.isValid());
surface->attachBuffer(Buffer::Ptr());
surface->commit(Surface::CommitFlag::None);
diff --git a/autotests/integration/placement_test.cpp b/autotests/integration/placement_test.cpp
index a116b8477b..a7f9dbfc76 100644
--- a/autotests/integration/placement_test.cpp
+++ b/autotests/integration/placement_test.cpp
@@ -22,7 +22,7 @@ along with this program. If not, see .
#include "kwin_wayland_test.h"
#include "platform.h"
#include "screens.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -89,7 +89,7 @@ void TestPlacement::cleanup()
void TestPlacement::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
@@ -215,7 +215,7 @@ void TestPlacement::testPlaceCentered()
QScopedPointer surface(Test::createSurface());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::red);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::red);
QVERIFY(client);
QCOMPARE(client->geometry(), QRect(590, 487, 100, 50));
@@ -237,7 +237,7 @@ void TestPlacement::testPlaceUnderMouse()
QScopedPointer surface(Test::createSurface());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::red);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::red);
QVERIFY(client);
QCOMPARE(client->geometry(), QRect(151, 276, 100, 50));
@@ -256,21 +256,21 @@ void TestPlacement::testPlaceCascaded()
QScopedPointer surface1(Test::createSurface());
QScopedPointer shellSurface1(Test::createXdgShellStableSurface(surface1.data()));
- ShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::red);
+ XdgShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::red);
QVERIFY(client1);
QCOMPARE(client1->pos(), QPoint(0, 0));
QCOMPARE(client1->size(), QSize(100, 50));
QScopedPointer surface2(Test::createSurface());
QScopedPointer shellSurface2(Test::createXdgShellStableSurface(surface2.data()));
- ShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
QVERIFY(client2);
QCOMPARE(client2->pos(), client1->pos() + workspace()->cascadeOffset(client2));
QCOMPARE(client2->size(), QSize(100, 50));
QScopedPointer surface3(Test::createSurface());
QScopedPointer shellSurface3(Test::createXdgShellStableSurface(surface3.data()));
- ShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::green);
+ XdgShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::green);
QVERIFY(client3);
QCOMPARE(client3->pos(), client2->pos() + workspace()->cascadeOffset(client3));
QCOMPARE(client3->size(), QSize(100, 50));
@@ -294,20 +294,20 @@ void TestPlacement::testPlaceRandom()
QScopedPointer surface1(Test::createSurface());
QScopedPointer shellSurface1(Test::createXdgShellStableSurface(surface1.data()));
- ShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::red);
+ XdgShellClient *client1 = Test::renderAndWaitForShown(surface1.data(), QSize(100, 50), Qt::red);
QVERIFY(client1);
QCOMPARE(client1->size(), QSize(100, 50));
QScopedPointer surface2(Test::createSurface());
QScopedPointer shellSurface2(Test::createXdgShellStableSurface(surface2.data()));
- ShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client2 = Test::renderAndWaitForShown(surface2.data(), QSize(100, 50), Qt::blue);
QVERIFY(client2);
QVERIFY(client2->pos() != client1->pos());
QCOMPARE(client2->size(), QSize(100, 50));
QScopedPointer surface3(Test::createSurface());
QScopedPointer shellSurface3(Test::createXdgShellStableSurface(surface3.data()));
- ShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::green);
+ XdgShellClient *client3 = Test::renderAndWaitForShown(surface3.data(), QSize(100, 50), Qt::green);
QVERIFY(client3);
QVERIFY(client3->pos() != client1->pos());
QVERIFY(client3->pos() != client2->pos());
diff --git a/autotests/integration/plasma_surface_test.cpp b/autotests/integration/plasma_surface_test.cpp
index 0e3d8ad77c..1edceb0d0c 100644
--- a/autotests/integration/plasma_surface_test.cpp
+++ b/autotests/integration/plasma_surface_test.cpp
@@ -20,7 +20,7 @@ along with this program. If not, see .
#include "kwin_wayland_test.h"
#include "platform.h"
#include "cursor.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -71,7 +71,7 @@ private:
void PlasmaSurfaceTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
@@ -110,7 +110,7 @@ void PlasmaSurfaceTest::testRoleOnAllDesktops_data()
void PlasmaSurfaceTest::testRoleOnAllDesktops()
{
- // this test verifies that a ShellClient is set on all desktops when the role changes
+ // this test verifies that a XdgShellClient is set on all desktops when the role changes
QScopedPointer surface(Test::createSurface());
QVERIFY(!surface.isNull());
QScopedPointer shellSurface(Test::createXdgShellStableSurface(surface.data()));
diff --git a/autotests/integration/pointer_constraints_test.cpp b/autotests/integration/pointer_constraints_test.cpp
index 802888d2a0..7aea27c543 100644
--- a/autotests/integration/pointer_constraints_test.cpp
+++ b/autotests/integration/pointer_constraints_test.cpp
@@ -22,7 +22,7 @@ along with this program. If not, see
diff --git a/autotests/integration/kwin_wayland_test.h b/autotests/integration/kwin_wayland_test.h
index de307f83f3..237f20bfa7 100644
--- a/autotests/integration/kwin_wayland_test.h
+++ b/autotests/integration/kwin_wayland_test.h
@@ -58,7 +58,7 @@ class Xwayland;
}
class AbstractClient;
-class ShellClient;
+class XdgShellClient;
class WaylandTestApplication : public ApplicationWaylandAbstract
{
@@ -181,15 +181,15 @@ void render(KWayland::Client::Surface *surface, const QSize &size, const QColor
void render(KWayland::Client::Surface *surface, const QImage &img);
/**
* Waits till a new ShellClient is shown and returns the created ShellClient.
* If no ShellClient gets shown during @p timeout @c null is returned.
*/
-ShellClient *waitForWaylandWindowShown(int timeout = 5000);
+XdgShellClient *waitForWaylandWindowShown(int timeout = 5000);
/**
* Combination of @link{render} and @link{waitForWaylandWindowShown}.
*/
-ShellClient *renderAndWaitForShown(KWayland::Client::Surface *surface, const QSize &size, const QColor &color, const QImage::Format &format = QImage::Format_ARGB32, int timeout = 5000);
+XdgShellClient *renderAndWaitForShown(KWayland::Client::Surface *surface, const QSize &size, const QColor &color, const QImage::Format &format = QImage::Format_ARGB32, int timeout = 5000);
/**
* Waits for the @p client to be destroyed.
@@ -181,15 +181,15 @@ void render(KWayland::Client::Surface *surface, const QSize &size, const QColor
void render(KWayland::Client::Surface *surface, const QImage &img);
/**
- * Waits till a new ShellClient is shown and returns the created ShellClient.
- * If no ShellClient gets shown during @p timeout @c null is returned.
+ * Waits till a new XdgShellClient is shown and returns the created XdgShellClient.
+ * If no XdgShellClient gets shown during @p timeout @c null is returned.
*/
diff --git a/autotests/integration/maximize_test.cpp b/autotests/integration/maximize_test.cpp
index c2085eeb8e..e951b1cfbb 100644
--- a/autotests/integration/maximize_test.cpp
+++ b/autotests/integration/maximize_test.cpp
@@ -22,7 +22,7 @@ along with this program. If not, see .
#include "decorations/decorationbridge.h"
#include "decorations/settings.h"
#include "platform.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
@@ -61,7 +61,7 @@ private Q_SLOTS:
void TestMaximized::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
@@ -103,7 +103,7 @@ void TestMaximized::cleanup()
void TestMaximized::testMaximizedPassedToDeco()
{
// this test verifies that when a ShellClient gets maximized the Decoration receives the signal
// Create the test client.
QScopedPointer surface(Test::createSurface());
@@ -202,7 +202,7 @@ void TestMaximized::testInitiallyMaximized()
// Now let's render in an incorrect size.
shellSurface->ackConfigure(configureRequestedSpy.last().at(2).value());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
QCOMPARE(client->geometry(), QRect(0, 0, 100, 50));
QEXPECT_FAIL("", "Should go out of maximzied", Continue);
@@ -249,7 +249,7 @@ void TestMaximized::testBorderlessMaximizedWindow()
// Map the client.
shellSurface->ackConfigure(configureRequestedSpy.last().at(2).value());
- ShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
QVERIFY(client);
QVERIFY(client->isActive());
QCOMPARE(client->maximizeMode(), MaximizeMode::MaximizeRestore);
@@ -326,7 +326,7 @@ void TestMaximized::testBorderlessMaximizedWindowNoClientSideDecoration()
auto client = Test::renderAndWaitForShown(surface.data(), QSize(100, 50), Qt::blue);
- QSignalSpy geometryChangedSpy(client, &ShellClient::geometryChanged);
+ QSignalSpy geometryChangedSpy(client, &XdgShellClient::geometryChanged);
QVERIFY(geometryChangedSpy.isValid());
QSignalSpy sizeChangeRequestedSpy(xdgShellSurface.data(), &XdgShellSurface::sizeChanged);
QVERIFY(sizeChangeRequestedSpy.isValid());
@@ -103,7 +103,7 @@ void TestMaximized::cleanup()
void TestMaximized::testMaximizedPassedToDeco()
{
- // this test verifies that when a ShellClient gets maximized the Decoration receives the signal
+ // this test verifies that when a XdgShellClient gets maximized the Decoration receives the signal
// Create the test client.
QScopedPointer surface(Test::createSurface());
diff --git a/autotests/integration/plasmawindow_test.cpp b/autotests/integration/plasmawindow_test.cpp
index 7999e6c84b..a9bee087d2 100644
--- a/autotests/integration/plasmawindow_test.cpp
+++ b/autotests/integration/plasmawindow_test.cpp
@@ -25,7 +25,7 @@ along with this program. If not, see .
#include "screens.h"
#include "wayland_server.h"
#include "workspace.h"
-#include "shell_client.h"
+#include "xdgshellclient.h"
#include
#include
@@ -68,7 +68,7 @@ private:
void PlasmaWindowTest::initTestCase()
{
- qRegisterMetaType();
+ qRegisterMetaType();
qRegisterMetaType();
QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
QVERIFY(workspaceCreatedSpy.isValid());
@@ -245,7 +245,7 @@ void PlasmaWindowTest::testPopupWindowNoPlasmaWindow()
// first create the parent window
QScopedPointer parentSurface(Test::createSurface());
QScopedPointer parentShellSurface(Test::createXdgShellStableSurface(parentSurface.data()));
- ShellClient *parentClient = Test::renderAndWaitForShown(parentSurface.data(), QSize(100, 50), Qt::blue);
+ XdgShellClient *parentClient = Test::renderAndWaitForShown(parentSurface.data(), QSize(100, 50), Qt::blue);
QVERIFY(parentClient);
QVERIFY(plasmaWindowCreatedSpy.wait());
QCOMPARE(plasmaWindowCreatedSpy.count(), 1);
@@ -256,7 +256,7 @@ void PlasmaWindowTest::testPopupWindowNoPlasmaWindow()
positioner.setGravity(Qt::BottomEdge | Qt::RightEdge);
QScopedPointer popupSurface(Test::createSurface());
QScopedPointer popupShellSurface(Test::createXdgShellStablePopup(popupSurface.data(), parentShellSurface.data(), positioner));
- ShellClient *popupClient = Test::renderAndWaitForShown(popupSurface.data(), positioner.initialSize(), Qt::blue);
+ XdgShellClient *popupClient = Test::renderAndWaitForShown(popupSurface.data(), positioner.initialSize(), Qt::blue);
QVERIFY(popupClient);
QVERIFY(!plasmaWindowCreatedSpy.wait(100));
QCOMPARE(plasmaWindowCreatedSpy.count(), 1);
@@ -274,13 +274,13 @@ void PlasmaWindowTest::testLockScreenNoPlasmaWindow()
QSignalSpy plasmaWindowCreatedSpy(m_windowManagement, &PlasmaWindowManagement::windowCreated);
QVERIFY(plasmaWindowCreatedSpy.isValid());
// this time we use a QSignalSpy on ShellClient as it'a a little bit more complex setup
QSignalSpy clientAddedSpy(waylandServer(), &WaylandServer::shellClientAdded);
QVERIFY(clientAddedSpy.isValid());
// lock
ScreenLocker::KSldApp::self()->lock(ScreenLocker::EstablishLock::Immediate);
QVERIFY(clientAddedSpy.wait());
- QVERIFY(clientAddedSpy.first().first().value()->isLockScreen());
+ QVERIFY(clientAddedSpy.first().first().value()->isLockScreen());
// should not be sent to the client
QVERIFY(plasmaWindowCreatedSpy.isEmpty());
QVERIFY(!plasmaWindowCreatedSpy.wait());
@@ -274,13 +274,13 @@ void PlasmaWindowTest::testLockScreenNoPlasmaWindow()
QSignalSpy plasmaWindowCreatedSpy(m_windowManagement, &PlasmaWindowManagement::windowCreated);
QVERIFY(plasmaWindowCreatedSpy.isValid());
- // this time we use a QSignalSpy on ShellClient as it'a a little bit more complex setup
+ // this time we use a QSignalSpy on XdgShellClient as it'a a little bit more complex setup
QSignalSpy clientAddedSpy(waylandServer(), &WaylandServer::shellClientAdded);
QVERIFY(clientAddedSpy.isValid());